Struct dlc_trie::OracleNumericInfo
source · pub struct OracleNumericInfo {
pub base: usize,
pub nb_digits: Vec<usize>,
}Expand description
Information about the base and number of digits used by the oracle.
Fields
base: usizeThe base in which the oracle will represent the outcome value.
nb_digits: Vec<usize>The number of digits that each oracle will use to represent the outcome value.
Implementations
sourceimpl OracleNumericInfo
impl OracleNumericInfo
sourcepub fn get_min_nb_digits(&self) -> usize
pub fn get_min_nb_digits(&self) -> usize
Return the minimum number of digits supported by an oracle in the group.
sourcepub fn has_diff_nb_digits(&self) -> bool
pub fn has_diff_nb_digits(&self) -> bool
Returns whether oracles have varying number of digits.